from django.http import JsonResponse
from django.shortcuts import get_object_or_404, render
from django.template.loader import render_to_string
from wagtail.admin.utils import permission_denied
from wagtail.images import get_image_model
from wagtail.images.permissions import permission_policy

from .forms import MultiImageEditForm

Image = get_image_model()


def multi_image_edit(request):
    images = Image.objects.filter(id__in=request.GET.getlist("id"))
    if request.method == "GET":
        forms = []
        for image in images:
            instance = get_object_or_404(Image, id=image.id)
            if not permission_policy.user_has_permission_for_instance(
                request.user, "change", instance
            ):
                return permission_denied(request)

            form = MultiImageEditForm(
                request.POST or None, instance=instance, prefix="image-%d" % instance.id
            )
            forms.append(form)
        return render(request, "wagtail_multi_image_edit/multi_edit.html", {"forms": forms})
    elif request.method == "POST":
        image_id = request.POST["image_id"]
        instance = Image.objects.get(id=image_id)

        if not permission_policy.user_has_permission_for_instance(
            request.user, "change", instance
        ):
            return permission_denied(request)

        form = MultiImageEditForm(
            request.POST, instance=instance, prefix="image-%d" % instance.id
        )

        if form.is_valid():
            form.save()
            return JsonResponse({"success": True})
        else:
            return JsonResponse(
                {
                    "success": False,
                    "form": render_to_string(
                        "wagtail_multi_image_edit/_multi_edit_form.html",
                        {"image": instance, "form": form},
                        request=request,
                    ),
                }
            )



from django.templatetags.static import static
from django.utils.html import format_html
from django.utils.safestring import mark_safe
from wagtail.core import hooks


@hooks.register("insert_global_admin_js")
def global_admin_js():
    return mark_safe(
        '<script src="%s"></script>'
        % static("/wagtail_multi_image_edit/admin/js/wagtail_multi_image_edit.js")
    )


@hooks.register("insert_global_admin_css")
def global_admin_css():
    return format_html(
        '<link rel="stylesheet" href="%s">'
        % static("/wagtail_multi_image_edit/admin/css/wagtail_multi_image_edit.css")
    )



from django.contrib import admin
from django.urls import include, path
from django.conf.urls import include, url

from wagtail.admin import urls as wagtailadmin_urls
from wagtail.core import urls as wagtail_multi_image_editurls
from wagtail.documents import urls as wagtaildocs_urls
from wagtail_multi_image_edit.views import multi_image_edit


private_urlpatterns = [
    url(r'^admin/images/multi-edit/', multi_image_edit, name='multi_image_edit'),
    path('django-admin/', admin.site.urls),
    path('admin/', include(wagtailadmin_urls)),
    path('documents/', include(wagtaildocs_urls)),
]

urlpatterns = [
]

urlpatterns = private_urlpatterns + urlpatterns + [
    # Add Wagtail URLs at the end.
    # Wagtail cache-control is set on the page models's serve methods.
]



import os

PROJECT_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
BASE_DIR = os.path.dirname(PROJECT_DIR)


SECRET_KEY = 'not so secret'

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': 'db.sqlite3',
    }
}

INSTALLED_APPS = [

    'wagtail.contrib.styleguide',
    'wagtail.contrib.routable_page',
    'wagtail.contrib.frontend_cache',
    'wagtail.contrib.settings',
    'wagtail.contrib.modeladmin',
    'wagtail.contrib.table_block',
    'wagtail.contrib.forms',
    'wagtail.embeds',
    'wagtail.sites',
    'wagtail.users',
    'wagtail.snippets',
    'wagtail.documents',
    'wagtail.admin',
    'wagtail.images',
    'wagtail.core',

    'taggit',

    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.sitemaps',
    # Add your app here
    'wagtail_multi_image_edit',
]


MIDDLEWARE = [
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',

    'wagtail.core.middleware.SiteMiddleware',
]

ROOT_URLCONF = 'wagtail_multi_image_edit.tests.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'APP_DIRS': True,
        'DIRS': [
            'wagtail_multi_image_edit/templates',
            'wagtail_multi_image_edit/templates/wagtailimages/images',
            ],
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
                'wagtail.contrib.settings.context_processors.settings',
            ],
        },
    },
]

WAGTAIL_SITE_NAME = 'llama-savers'
USE_TZ = True

MULTI_IMAGE_EDIT_FIELDS = [
    'title',
    'collection',
]



#!/usr/bin/env python
"""
Installs yourapp.
"""

from setuptools import setup, find_packages
from os import path

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, "README.md"), encoding="utf-8") as f:
    long_description = f.read()


setup(
    name="Wagtail Multi Image Edit",
    version="0.0.5",
    description="Wagtail Multi Image Edit",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/kevinhowbrook/wagtail-multi-image-edit",
    author="Kevin Howbrook",
    author_email="kbhowbrook@gmail.com",
    license="MIT License",
    packages=find_packages(exclude=["tests*"]),
    include_package_data=True,
    install_requires=["wagtail"],
)



from django.conf import settings
from wagtail.images import get_image_model
from wagtail.images.forms import get_image_form

Image = get_image_model()

ImageForm = get_image_form(Image)


class MultiImageEditForm(ImageForm):
    class Meta(ImageForm.Meta):
        fields = settings.MULTI_IMAGE_EDIT_FIELDS



from django.conf import settings

from django.contrib.auth import get_user_model
from django.urls import reverse
from wagtail.images import get_image_model
from wagtail.images.tests.utils import (get_test_image_file,
                                        get_test_image_file_jpeg)
from wagtail.tests.utils import WagtailPageTests, WagtailTestUtils
from django.test import TestCase, override_settings


Image = get_image_model()


class MultiImageEditTests(TestCase, WagtailTestUtils):
    def setUp(self):
        super().setUp()
        self.login()
        image = Image.objects.create(title="Test image", file=get_test_image_file())
        self.image_id = image.id
        self.image_title = image.title

    def test_admin(self):
        response = self.client.get(reverse("wagtailadmin_home"))
        self.assertEqual(response.status_code, 200)

    def test_image_admin(self):
        response = self.client.get("/admin/images/")
        self.assertEqual(response.status_code, 200)

    def test_multi_image_edit_admin(self):
        response = self.client.get(reverse("multi_image_edit"))
        self.assertEqual(response.status_code, 200)

    def test_images_have_select_option(self):
        response = self.client.get("/admin/images/")
        self.assertContains(
            response,
            '<input type="checkbox" name="select_image" value="{}" class="toggle-select-row"/>'.format(
                self.image_id
            ),
        )

    # test the image is in the form
    def test_multi_edit_view(self):
        url = "{}?id={}".format(reverse("multi_image_edit"), self.image_id)
        response = self.client.get(url)
        self.assertEqual(response.status_code, 200)

    # test the form is there
    def test_multi_edit_view_form(self):
        url = "{}?id={}".format(reverse("multi_image_edit"), self.image_id)
        response = self.client.get(url)
        self.assertContains(
            response,
            '<form action="/admin/images/multi-edit/" method="POST" novalidate class="multi-image-edit-form">'.format(
                self.image_id
            ),
        )

    # test posting data to the form
    def test_image_update_post(self):
        # Submit
        url = "{}?id={}".format(reverse("multi_image_edit"), self.image_id)
        response = self.client.get(url)
        post_data = {
            "image-{}-title".format(self.image_id): "Dana Scully",
            "image_id": self.image_id,
        }
        response = self.client.post(reverse("multi_image_edit"), post_data)
        image = Image.objects.get(id=self.image_id)
        self.assertEqual("Dana Scully", image.title)
